<?php
namespace Bushelpowered\Api\Fulfillment\Contract\V1;

use \Bushelpowered\Api\Common\Request\IdRequest;
use \Bushelpowered\Api\Fulfillment\Contract\V1\Response\ContractDetailGetResponse;
use \Bushelpowered\Api\Common\BadRequest;
use \Bushelpowered\Api\Common\ConstraintViolation;
use \Bushelpowered\Api\Common\NotAuthenticated;
use \Bushelpowered\Api\Common\NotAuthorized;
use \Bushelpowered\Api\Common\NotFound;
use \Bidl\Php\Core\Builtins\UnknownError;

class GetContractById 
{
    public function __construct(public \Bidl\Php\Core\BidlClient $client)
    {
    }
    
    public function call(IdRequest $request, $headers): ContractDetailGetResponse | BadRequest | ConstraintViolation | NotAuthenticated | NotAuthorized | NotFound | UnknownError
    {
         return $this->client->call('api/fulfillment/contract/v1/GetContractById', $request, new GetContractByIdResponseWrapper(), $headers)->response;
    }
}

class GetContractByIdResponseWrapper implements \Bidl\Php\Core\BIDlResponse {

    /** @var ContractDetailGetResponse | BadRequest | ConstraintViolation | NotAuthenticated | NotAuthorized | NotFound | UnknownError */
    public $response;

    public function __construct()
    {
        $this->mapper = new \JsonMapper();
    }
    
    public function fromJson($data) 
    {
        switch($data->type) {
          case 'api.fulfillment.contract.v1#GetContractByIdSuccess':
            $empty = (new \ReflectionClass(\Bushelpowered\Api\Fulfillment\Contract\V1\Response\ContractDetailGetResponse::class))->newInstanceWithoutConstructor();
            $this->response = $this->mapper->map($data, $empty);
            break;
          case 'api.common#BadRequest':
            $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\BadRequest::class))->newInstanceWithoutConstructor();
            $this->response = $this->mapper->map($data, $empty);
            break;
          case 'api.common#ConstraintViolation':
            $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\ConstraintViolation::class))->newInstanceWithoutConstructor();
            $this->response = $this->mapper->map($data, $empty);
            break;
          case 'api.common#NotAuthenticated':
            $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthenticated::class))->newInstanceWithoutConstructor();
            $this->response = $this->mapper->map($data, $empty);
            break;
          case 'api.common#NotAuthorized':
            $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotAuthorized::class))->newInstanceWithoutConstructor();
            $this->response = $this->mapper->map($data, $empty);
            break;
          case 'api.common#NotFound':
            $empty = (new \ReflectionClass(\Bushelpowered\Api\Common\NotFound::class))->newInstanceWithoutConstructor();
            $this->response = $this->mapper->map($data, $empty);
            break;
           default: 
             $this->response = new \Bidl\Php\Core\Builtins\UnknownError('The response was not a valid bidl response.');
        }
    }
}